<template>
  <j-modal
    :title="title"
    :width="width"
    :visible="visible"
    switchFullscreen
    @ok="handleOk"
    :okButtonProps="{ class:{'jee-hidden': disableSubmit} }"
    @cancel="handleCancel"
    cancelText="关闭">

    <j-vxe-table
      ref="editableDetailTable"
      :rowNumber="true"
      :rowSelection="false"
      :bordered="false"
      :alwaysEdit="true"
      :toolbar="false"
      keep-source
      :height="300"
      :loading="detail.loading"
      :dataSource="detail.dataSource"
      :columns="equipmentColumns"
      style="margin-top: 8px;" />

  </j-modal>

</template>

<script>

import { JVxeTableModelMixin } from '@/mixins/JVxeTableModelMixin.js'
import { JVXETypes } from '@/components/jeecg/JVxeTable'
import { getAction, postAction } from '../../../../api/manage'

export default {
  name: 'EamMajorPartialRepairDetailModal',
  mixins: [JVxeTableModelMixin],
  data() {
    return {
      title: '',
      width: 1200,
      visible: false,
      disableSubmit: false,
      equipmentOptions: [],
      detail: {
        loading: false,
        dataSource: []
      },
      url: {
        queryDetailList: '/eam/eamMajorPartialRepairDetail/list',
        fillResult: '/eam/eamMajorPartialRepair/fillResult'
      }
    }
  },
  computed: {
    equipmentColumns() {
      return [
        {
          title: '设备',
          key: 'equipmentId_dictText',
          type: JVXETypes.normal,
          width: '25%',
          align: 'center'
        },
        {
          title: '单价',
          key: 'unitPrice',
          type: JVXETypes.normal,
          width: '10%',
          align: 'center'
        },
        {
          title: '维修结果',
          key: 'repairResult',
          type: JVXETypes.textarea,
          width: '30%',
          align: 'center',
          validateRules: [{ required: true, message: '维修结果不能为空！' }]
        },
        {
          title: '维修描述',
          key: 'repairDescription',
          type: JVXETypes.textarea,
          width: '30%',
          align: 'center',
          validateRules: [{ required: true, message: '维修描述不能为空！' }]
        }
      ];
    }
  },
  methods: {
    open(record) {
      this.visible = true
      getAction(this.url.queryDetailList, { repairId: record.id }).then((res) => {
        if (res.success) {
          if (res.result.total) {
            this.detail.dataSource = res.result.records
          }
        }
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    async handleOk() {
        // 👇 触发表格校验
        const errMap = await this.$refs.editableDetailTable.validateTable();

        if (errMap) {
          return;
        }

        // 校验通过，获取表格数据
        const tableData = this.$refs.editableDetailTable.getTableData();

        postAction(this.url.fillResult, tableData).then((res) => {
          if (res.success) {
            this.$message.success(res.message)
            // 👇 提交成功后关闭弹窗
            this.submitCallback();
          } else {
            this.$message.warning(res.message)
          }
        })
    },
    submitCallback() {
      this.$emit('ok')
      this.visible = false
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>